@@ -1,6 +1,6 @@
 /*
 parolottero
-Copyright (C) 2021-2022 Salvo "LtWorf" Tomaselli
+Copyright (C) 2021-2024 Salvo "LtWorf" Tomaselli
 
 This program is free software: you can redistribute it and/or modify
 it under the terms of the GNU Affero General Public License as
@@ -26,21 +26,30 @@ author Salvo "LtWorf" Tomaselli <tiposchi@tiscali.it>
 #include <QList>
 #include "language.h"
 
+static void* singleton = nullptr;
+
 class LanguageManager : public QObject
 {
     Q_OBJECT
 public:
-    explicit LanguageManager(QObject *parent = nullptr);
+    static LanguageManager* getLanguageManager() {
+        if (singleton == nullptr)
+            singleton = new LanguageManager();
+        return (LanguageManager*)singleton;
+    }
 
 signals:
 
 public slots:
     QStringList languages();
     Language* get_language(unsigned int);
+    void rescan();
 private:
+    explicit LanguageManager(QObject *parent = nullptr);
     QStringList languagenames;
     QStringList languagefilenames;
     QList<Language*> languages_loaded;
+    void unload_languages();
 };
 
 #endif // LANGUAGEMANAGER_H
